{
  am_pm_abbreviated => [
    "\N{U+043f}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043f}\N{U+043b}.",
    "\N{U+043f}\N{U+043e}\N{U+043f}\N{U+043b}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d.M.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "W. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' MMMM",
    "MMMMW-count-other" => "W. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d.M",
    Mdd => "d.M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y '\N{U+0433}'.",
    yMMMEd => "E, d MMM y '\N{U+0433}'.",
    yMMMM => "MMMM y '\N{U+0433}'.",
    yMMMd => "d MMM y '\N{U+0433}'.",
    yMd => "d.M.y",
    yQQQ => "QQQ y '\N{U+0433}'.",
    yQQQQ => "QQQQ y '\N{U+0433}'.",
    "yw-count-one" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' Y",
    "yw-count-other" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' Y",
  },
  code => "mk-MK",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d.M.y",
  date_format_short => "d.M.yy",
  datetime_format_full => "{1}, '\N{U+0432}\N{U+043e}' {0}",
  datetime_format_long => "{1}, '\N{U+0432}\N{U+043e}' {0}",
  datetime_format_medium => "{1}, '\N{U+0432}\N{U+043e}' {0}",
  datetime_format_short => "{1}, '\N{U+0432}\N{U+043e}' {0}",
  day_format_abbreviated => [
    "\N{U+043f}\N{U+043e}\N{U+043d}.",
    "\N{U+0432}\N{U+0442}\N{U+043e}.",
    "\N{U+0441}\N{U+0440}\N{U+0435}.",
    "\N{U+0447}\N{U+0435}\N{U+0442}.",
    "\N{U+043f}\N{U+0435}\N{U+0442}.",
    "\N{U+0441}\N{U+0430}\N{U+0431}.",
    "\N{U+043d}\N{U+0435}\N{U+0434}.",
  ],
  day_format_narrow => [
    "\N{U+043f}",
    "\N{U+0432}",
    "\N{U+0441}",
    "\N{U+0447}",
    "\N{U+043f}",
    "\N{U+0441}",
    "\N{U+043d}",
  ],
  day_format_wide => [
    "\N{U+043f}\N{U+043e}\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0441}\N{U+0440}\N{U+0435}\N{U+0434}\N{U+0430}",
    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e}\N{U+043a}",
    "\N{U+043f}\N{U+0435}\N{U+0442}\N{U+043e}\N{U+043a}",
    "\N{U+0441}\N{U+0430}\N{U+0431}\N{U+043e}\N{U+0442}\N{U+0430}",
    "\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+0430}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+043f}\N{U+043e}\N{U+043d}.",
    "\N{U+0432}\N{U+0442}\N{U+043e}.",
    "\N{U+0441}\N{U+0440}\N{U+0435}.",
    "\N{U+0447}\N{U+0435}\N{U+0442}.",
    "\N{U+043f}\N{U+0435}\N{U+0442}.",
    "\N{U+0441}\N{U+0430}\N{U+0431}.",
    "\N{U+043d}\N{U+0435}\N{U+0434}.",
  ],
  day_stand_alone_narrow => [
    "\N{U+043f}",
    "\N{U+0432}",
    "\N{U+0441}",
    "\N{U+0447}",
    "\N{U+043f}",
    "\N{U+0441}",
    "\N{U+043d}",
  ],
  day_stand_alone_wide => [
    "\N{U+043f}\N{U+043e}\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0441}\N{U+0440}\N{U+0435}\N{U+0434}\N{U+0430}",
    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e}\N{U+043a}",
    "\N{U+043f}\N{U+0435}\N{U+0442}\N{U+043e}\N{U+043a}",
    "\N{U+0441}\N{U+0430}\N{U+0431}\N{U+043e}\N{U+0442}\N{U+0430}",
    "\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+0430}",
  ],
  era_abbreviated => [
    "\N{U+043f}.\N{U+043d}.\N{U+0435}.",
    "\N{U+043d}.\N{U+0435}.",
  ],
  era_narrow => [
    "\N{U+043f}.\N{U+043d}.\N{U+0435}.",
    "\N{U+043d}.\N{U+0435}.",
  ],
  era_wide => [
    "\N{U+043f}\N{U+0440}\N{U+0435}\N{U+0434} \N{U+043d}\N{U+0430}\N{U+0448}\N{U+0430}\N{U+0442}\N{U+0430} \N{U+0435}\N{U+0440}\N{U+0430}",
    "\N{U+043e}\N{U+0434} \N{U+043d}\N{U+0430}\N{U+0448}\N{U+0430}\N{U+0442}\N{U+0430} \N{U+0435}\N{U+0440}\N{U+0430}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a, %d %b %H:%M:%S %Z %Y",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a, %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Macedonian",
  month_format_abbreviated => [
    "\N{U+0458}\N{U+0430}\N{U+043d}.",
    "\N{U+0444}\N{U+0435}\N{U+0432}.",
    "\N{U+043c}\N{U+0430}\N{U+0440}.",
    "\N{U+0430}\N{U+043f}\N{U+0440}.",
    "\N{U+043c}\N{U+0430}\N{U+0458}",
    "\N{U+0458}\N{U+0443}\N{U+043d}.",
    "\N{U+0458}\N{U+0443}\N{U+043b}.",
    "\N{U+0430}\N{U+0432}\N{U+0433}.",
    "\N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}.",
    "\N{U+043e}\N{U+043a}\N{U+0442}.",
    "\N{U+043d}\N{U+043e}\N{U+0435}\N{U+043c}.",
    "\N{U+0434}\N{U+0435}\N{U+043a}.",
  ],
  month_format_narrow => [
    "\N{U+0458}",
    "\N{U+0444}",
    "\N{U+043c}",
    "\N{U+0430}",
    "\N{U+043c}",
    "\N{U+0458}",
    "\N{U+0458}",
    "\N{U+0430}",
    "\N{U+0441}",
    "\N{U+043e}",
    "\N{U+043d}",
    "\N{U+0434}",
  ],
  month_format_wide => [
    "\N{U+0458}\N{U+0430}\N{U+043d}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0438}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0458}",
    "\N{U+0458}\N{U+0443}\N{U+043d}\N{U+0438}",
    "\N{U+0458}\N{U+0443}\N{U+043b}\N{U+0438}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+043e}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043d}\N{U+043e}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0458}\N{U+0430}\N{U+043d}.",
    "\N{U+0444}\N{U+0435}\N{U+0432}.",
    "\N{U+043c}\N{U+0430}\N{U+0440}.",
    "\N{U+0430}\N{U+043f}\N{U+0440}.",
    "\N{U+043c}\N{U+0430}\N{U+0458}",
    "\N{U+0458}\N{U+0443}\N{U+043d}.",
    "\N{U+0458}\N{U+0443}\N{U+043b}.",
    "\N{U+0430}\N{U+0432}\N{U+0433}.",
    "\N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}.",
    "\N{U+043e}\N{U+043a}\N{U+0442}.",
    "\N{U+043d}\N{U+043e}\N{U+0435}\N{U+043c}.",
    "\N{U+0434}\N{U+0435}\N{U+043a}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+0458}",
    "\N{U+0444}",
    "\N{U+043c}",
    "\N{U+0430}",
    "\N{U+043c}",
    "\N{U+0458}",
    "\N{U+0458}",
    "\N{U+0430}",
    "\N{U+0441}",
    "\N{U+043e}",
    "\N{U+043d}",
    "\N{U+0434}",
  ],
  month_stand_alone_wide => [
    "\N{U+0458}\N{U+0430}\N{U+043d}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0438}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0458}",
    "\N{U+0458}\N{U+0443}\N{U+043d}\N{U+0438}",
    "\N{U+0458}\N{U+0443}\N{U+043b}\N{U+0438}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+043e}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043d}\N{U+043e}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
  ],
  name => "Macedonian North Macedonia",
  native_language => "\N{U+043c}\N{U+0430}\N{U+043a}\N{U+0435}\N{U+0434}\N{U+043e}\N{U+043d}\N{U+0441}\N{U+043a}\N{U+0438}",
  native_name => "\N{U+043c}\N{U+0430}\N{U+043a}\N{U+0435}\N{U+0434}\N{U+043e}\N{U+043d}\N{U+0441}\N{U+043a}\N{U+0438} \N{U+0421}\N{U+0435}\N{U+0432}\N{U+0435}\N{U+0440}\N{U+043d}\N{U+0430} \N{U+041c}\N{U+0430}\N{U+043a}\N{U+0435}\N{U+0434}\N{U+043e}\N{U+043d}\N{U+0438}\N{U+0458}\N{U+0430}",
  native_script => undef,
  native_territory => "\N{U+0421}\N{U+0435}\N{U+0432}\N{U+0435}\N{U+0440}\N{U+043d}\N{U+0430} \N{U+041c}\N{U+0430}\N{U+043a}\N{U+0435}\N{U+0434}\N{U+043e}\N{U+043d}\N{U+0438}\N{U+0458}\N{U+0430}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0458}\N{U+0430}\N{U+043d}-\N{U+043c}\N{U+0430}\N{U+0440}",
    "\N{U+0430}\N{U+043f}\N{U+0440}-\N{U+0458}\N{U+0443}\N{U+043d}",
    "\N{U+0458}\N{U+0443}\N{U+043b}-\N{U+0441}\N{U+0435}\N{U+043f}",
    "\N{U+043e}\N{U+043a}\N{U+0442}-\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+043f}\N{U+0440}\N{U+0432}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
    "\N{U+0442}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0458}\N{U+0430}\N{U+043d}-\N{U+043c}\N{U+0430}\N{U+0440}",
    "\N{U+0430}\N{U+043f}\N{U+0440}-\N{U+0458}\N{U+0443}\N{U+043d}",
    "\N{U+0458}\N{U+0443}\N{U+043b}-\N{U+0441}\N{U+0435}\N{U+043f}",
    "\N{U+043e}\N{U+043a}\N{U+0442}-\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+043f}\N{U+0440}\N{U+0432}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
    "\N{U+0442}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
  ],
  script => undef,
  territory => "North Macedonia",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}
